@@ -22,7 +22,7 @@ class ConnError(Exception):
     pass
 
 class DroneApiConnector():
-    def __init__(self, token, vehicle_id, timeout=60, time_constant=20, conn_time=10, wait_for_drone_response=False):
+    def __init__(self, token, vehicle_id,ip_address='cloud',timeout=60, time_constant=20, conn_time=10, wait_for_drone_response=False):
         """
         Get namespace and make a websocket connection with the drone
         :param token: Personal Access Token assigned to the User (Flytbase Platform)
@@ -64,6 +64,8 @@ class DroneApiConnector():
             no_of_connections = int(no_of_connections) + 1
         self.id = no_of_connections
         self.wait_for_drone_response = not wait_for_drone_response
+        self.ip_address = ip_address
+
         header = {
             "Authorization": 'Token '+token,
             "VehicleID": vehicle_id,
@@ -71,7 +73,7 @@ class DroneApiConnector():
         }
         self.conn_time = conn_time
         job_request = dict(type="NEW_CONN", namespace=self.namespace, id=self.id, vehicleID=vehicle_id,
-                           timeout=self.timeout, header=header, conn_time = self.conn_time)
+                           ip_address=self.ip_address, timeout=self.timeout, header=header, conn_time = self.conn_time)
         add_to_job_requests(job_request)
 
         wst = threading.Thread(target=self.filter_unnecessary, args=())
@@ -556,7 +558,6 @@ class DroneApiConnector():
         result = self.get_realtime_data()
         while(True):
             if (('success' not in result) and ('/'+self.namespace+'/mavros/imu/data' in result['real_time'])):
-                #print(result)
                 if 'succeess' not in result['real_time']['/' + self.namespace + '/mavros/imu/data']['msg']:
                     Response = dict(
                         x=result['real_time']['/' + self.namespace + '/mavros/imu/data']['msg']['orientation']['x'],
@@ -594,7 +595,7 @@ class DroneApiConnector():
                             current = result['real_time']['/' + self.namespace + '/mavros/battery']['msg']['current'],
                             remaining = result['real_time']['/' + self.namespace + '/mavros/battery']['msg']['percentage'])
                 else:
-                    Response = dict(success = "False", reason = result['real_time']['/'+self.namespace+'/mavros/battery']['msg']['reason'])
+                    Response = dict(success="False", reason = result['real_time']['/'+self.namespace+'/mavros/battery']['msg']['reason'])
                 break
             else:
                 result = self.get_realtime_data()
@@ -842,6 +843,12 @@ class DroneApiConnector():
                     "success": c['values']['success'],
                     "message": c['values']['message']
                 }
+                if 'waypoints' in c['values']:
+                    d = {
+                        "success": c['values']['success'],
+                        "message": c['values']['message'],
+                        "waypoints": c['values']['waypoints']
+                    }
                 if 'param_info' in c['values']:
                     d = {
                         "success": c['values']['success'],
